==> entity_delete_log-1.0.0.tar.gz: entity_delete_log/src/Form/EntityDeleteLogSettingsForm.php <==
<?php

namespace Drupal\entity_delete_log\Form;

use Drupal\Core\Entity\ContentEntityType;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Render\Renderer;
use Drupal\Core\Link;
use Drupal\Core\Url;
use Drupal\Core\Extension\ExtensionPathResolver;

/**
 * Class EntityDeleteLogSettingsForm.
 */
class EntityDeleteLogSettingsForm extends ConfigFormBase {

  /**
   * Drupal\Core\Entity\EntityTypeManagerInterface definition.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * Drupal\Core\Render\Renderer definition.
   *
   * @var \Drupal\Core\Render\Renderer
   */
  protected $renderer;

  /**
   * Drupal\Core\Extension\ExtensionPathResolver definition.
   *
   * @var Drupal\Core\Extension\ExtensionPathResolver
   */
  protected $extensionPathResolver;

  /**
   * Constructs a new EntityDeleteLogSettingsForm object.
   */
  public function __construct(
    EntityTypeManagerInterface $entity_type_manager,
    Renderer $renderer,
    ExtensionPathResolver $extensionPathResolver
  ) {
    $this->entityTypeManager = $entity_type_manager;
    $this->renderer = $renderer;
    $this->extensionPathResolver = $extensionPathResolver;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('entity_type.manager'),
      $container->get('renderer'),
      $container->get('extension.path.resolver')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'entity_delete_log_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'entity_delete_log.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('entity_delete_log.settings');

    // Add some helpful links.
    $help_links = [
      Link::fromTextAndUrl('View the Entity Delete Log README',
          Url::fromUserInput('/' . $this->extensionPathResolver->getPath('module', 'entity_delete_log') . '/README.txt')),
      Link::fromTextAndUrl('View the Entity Delete Logs',
          Url::fromUserInput('/admin/reports/entity-delete-log')),
    ];
    $list = [
      '#theme' => 'item_list',
      '#items' => $help_links,
    ];
    $form['#prefix'] = $this->renderer->render($list);

    // Provide a list of checkboxes for the user to choose which entity
    // types will have delete logging enabled.
    $entity_definitions = array_filter($this->entityTypeManager->getDefinitions(), function ($definition) {
      return ($definition instanceof ContentEntityType) ? TRUE : FALSE;
    });
    $entity_keys = array_keys($entity_definitions);
    $entity_labels = array_map(function ($definition) {
      return $definition->getLabel()->render();
    }, $entity_definitions);

    $form['entity_types'] = [
      '#title' => $this->t('Entity Types to Log'),
      '#type' => 'checkboxes',
      '#options' => array_combine($entity_keys, $entity_labels),
      '#default_value' => ($config->get('entity_types')) ? $config->get('entity_types') : [],
      '#description' => $this->t('Select which entity types will be logged when deleted.'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->configFactory->getEditable('entity_delete_log.settings')
      ->set('entity_types', $form_state->getValue('entity_types'))
      ->save();
    parent::submitForm($form, $form_state);
  }

}

==> entity_delete_log-1.1.0.tar.gz: entity_delete_log/src/Form/EntityDeleteLogSettingsForm.php <==
<?php

namespace Drupal\entity_delete_log\Form;

use Drupal\Core\Entity\ContentEntityType;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Extension\ExtensionPathResolver;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Link;
use Drupal\Core\Render\Renderer;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\Core\Url;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides a form for configuring entity delete log settings.
 */
class EntityDeleteLogSettingsForm extends ConfigFormBase {

  /**
   * Drupal\Core\Entity\EntityTypeManagerInterface definition.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * The renderer service.
   *
   * @var \Drupal\Core\Render\Renderer
   */
  protected $renderer;

  /**
   * The extension path resolver.
   *
   * @var \Drupal\Core\Extension\ExtensionPathResolver
   */
  protected $extensionPathResolver;

  /**
   * Constructs a new EntityDeleteLogSettingsForm object.
   */
  public function __construct(
    EntityTypeManagerInterface $entity_type_manager,
    Renderer $renderer,
    ExtensionPathResolver $extensionPathResolver
  ) {
    $this->entityTypeManager = $entity_type_manager;
    $this->renderer = $renderer;
    $this->extensionPathResolver = $extensionPathResolver;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('entity_type.manager'),
      $container->get('renderer'),
      $container->get('extension.path.resolver')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'entity_delete_log_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'entity_delete_log.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('entity_delete_log.settings');

    // Add some helpful links.
    $help_links = [
      Link::fromTextAndUrl('View the Entity Delete Log README',
          Url::fromUserInput('/' . $this->extensionPathResolver->getPath('module', 'entity_delete_log') . '/README.txt')),
      Link::fromTextAndUrl('View the Entity Delete Logs',
          Url::fromUserInput('/admin/reports/entity-delete-log')),
    ];
    $list = [
      '#theme' => 'item_list',
      '#items' => $help_links,
    ];
    $form['#prefix'] = $this->renderer->render($list);

    // Provide a list of checkboxes for the user to choose which entity
    // types will have delete logging enabled.
    $entity_definitions = array_filter($this->entityTypeManager->getDefinitions(), function ($definition) {
      return ($definition instanceof ContentEntityType) ? TRUE : FALSE;
    });
    $entity_keys = array_keys($entity_definitions);
    $entity_labels = array_map(function ($definition) {
      $label = $definition->getLabel();
      return ($label instanceof TranslatableMarkup) ? $label->render() : $label;
    }, $entity_definitions);

    $form['entity_types'] = [
      '#title' => $this->t('Entity Types to Log'),
      '#type' => 'checkboxes',
      '#options' => array_combine($entity_keys, $entity_labels),
      '#default_value' => ($config->get('entity_types')) ? $config->get('entity_types') : [],
      '#description' => $this->t('Select which entity types will be logged when deleted.'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->configFactory->getEditable('entity_delete_log.settings')
      ->set('entity_types', $form_state->getValue('entity_types'))
      ->save();
    parent::submitForm($form, $form_state);
  }

}
